EUNKNOWN=-1
ECONCLOSE=1
EREADLEN=2
EWRITELEN=3
ESTRTOLONG=4
ERESPONSE=6
EKEEPALIVE=7
ENOCON=8
ECONUNKNOWN=20
ECONPROTOCOL=21
ECONREJECT=22
ECONUNAVAIBLE=23
ECONCREDENTIALS=24
ECONAUTH=25
ECONNOT=28
ECONLENGTH=29
ECONTIMEOUT=30
ESUBACKUNKNOWN=40
ESUBACKFAIL=44
STIMEOUT=0
SDELIVERED=1
SUNKNOWNPID=2